@@ -1,3 +1,5 @@
+from typing import Optional
+
 from pydantic import BaseModel, Field
 
 __all__ = ["ClientBaseForm"]
@@ -9,4 +11,10 @@ class ClientBaseForm(BaseModel):
     """
 
     client_id: str = Field(..., title="客户ID", max_length=100)
-    client_secret: str = Field(..., title="客户机密", max_length=255)
+    client_secret: Optional[str] = Field(
+        None,
+        title="客户机密",
+        max_length=255,
+        description="""部分接口不需要此参数
+例如: 获取登录地址""",
+    )
